@@ -10,8 +10,8 @@
 #define dNOOP
 #endif
 
-#ifndef gv_init_pvn
-#define gv_init_pvn(gv, stash, name, len, flags) gv_init(gv, stash, name, len, 0)
+#ifndef gv_init_sv
+#define gv_init_sv(gv, stash, sv, flags) gv_init(gv, stash, SvPVX(sv), SvLEN(sv), flags | SvUTF8(sv))
 #endif
 
 #endif
